==> pyofss-0.7.tar.gz: pyofss-0.7/examples/agrawal_book/chapter-4/fig_4-19/fig_4-19.py <==

# ==============================================================================
"""
    Copyright (C) 2012  David Bolt

	 This file is part of pyofss.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
# ==============================================================================

from pyofss import *
# ==============================================================================
domain = Domain( bit_width = 2.0, samples_per_bit = 4096 )

s = 0.01
width = 1.0 / (s * domain.centre_omega)

P_ts = []
zs = [0.0, 10.0, 20.0]
# ==============================================================================
for z in zs:
   system = System( domain )
   system.add( Gaussian(peak_power = 1.0, width = width) )
   system.add( Fibre(length = z, gamma = 1.0, total_steps = 200,
                     self_steepening = True, method = "RK4IP") )
   system.run()
   # ===========================================================================
   field = system.fields['fibre']
   P_ts.append( temporal_power(field) )
# ==============================================================================
multi_plot( system.domain.t, P_ts, zs, labels["t"], labels["P_t"],
            ["$z = {0:.0f} \, km$"], (0.7, 1.3), filename = "4-19.png" )
# ==============================================================================

==> pyofss-0.8.tar.gz: pyofss-0.8/examples/agrawal_book/chapter-4/fig_4-13/fig_4-13.py <==

# ==============================================================================
"""
    Copyright (C) 2011, 2012  David Bolt

	 This file is part of pyofss.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
# ==============================================================================

from pyofss import *
# ==============================================================================
system = System( Domain(bit_width = 400.0, samples_per_bit = 2048) )
system.add( Gaussian(peak_power = 1.0, width = 30.0, C = -20.0) )
system.add( Fibre(length = 72.0, beta = [0.0, 0.0, 1.0, 0.0],
                  gamma = 1.0, total_steps = 500) )
system.run()
# ==============================================================================
P_t = temporal_power( system.fields['fibre'] )
P_nu_normalised = spectral_power( system.fields['fibre'], True )
# ==============================================================================
double_plot( system.domain.t, P_t, system.domain.nu, P_nu_normalised,
             labels['t'], labels['P_t'], labels['nu'], labels['P_nu'],
             x_range = (50.0, 350.0), X_range = (192.6, 193.6),
             filename = "4-13" )
# ==============================================================================
